===============================
 Invenio-OAuth2Server v1.0.0a6
===============================

Invenio-OAuth2Server v1.0.0a6 was released on June 1, 2016.

About
-----

Invenio module that implements OAuth 2 server.

*This is an experimental developer preview release.*

What's new
----------

- Refactores package.

Installation
------------

   $ pip install invenio-oauth2server==1.0.0a6

Documentation
-------------

   http://pythonhosted.org/invenio-oauth2server/

Happy hacking and thanks for flying Invenio-OAuth2Server.

| Invenio Development Team
|   Email: info@invenio-software.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-oauth2server
|   URL: http://invenio-software.org
